@@ -25,33 +25,19 @@
 
 #include <glib.h>
 
-#include "playlist.h"
-#include "plugin.h"
-
-typedef struct _PlaybackInfo PlaybackInfo;
-
-struct _PlaybackInfo {
-    gint bitrate;
-    gint frequency;
-    gint n_channels;
-};
-
+void playback_play (gint seek_time, gboolean pause);
 gint playback_get_time(void);
-gint playback_get_length(void);
-void playback_initiate(void);
 void playback_pause(void);
 void playback_stop(void);
-gboolean playback_play_file(PlaylistEntry *entry);
 gboolean playback_get_playing(void);
 gboolean playback_get_paused(void);
 void playback_seek(gint time);
-void playback_seek_relative(gint offset);
-void playback_eof(void);
-void playback_error(void);
-InputPlayback *playback_new(void);
-void playback_free(InputPlayback *);
-void playback_run(InputPlayback *);
-void playback_get_sample_params(gint *bitrate, gint *frequency, gint *n_channels);
-void playback_set_sample_params(gint bitrate, gint frequency, gint n_channels);
+
+gchar * playback_get_title (void);
+gint playback_get_length (void);
+void playback_get_info (gint * bitrate, gint * samplerate, gint * channels);
+
+void input_get_volume(gint * l, gint * r);
+void input_set_volume(gint l, gint r);
 
 #endif /* AUDACIOUS_PLAYBACK_H */
